<?php
/**
 * Copyright © Magento, Inc. All rights reserved.
 * See COPYING.txt for license details.
 */
namespace FiloBlu\GuestWishlist\Controller\Index;

use Magento\Framework\App\Action;
use Magento\Framework\Data\Form\FormKey\Validator;
use Magento\Framework\Exception\NotFoundException;
use Magento\Framework\Controller\ResultFactory;
use Magento\Wishlist\Controller\WishlistProviderInterface;
use Magento\Wishlist\Helper\Data as WishlistHelper;

/**
 * @SuppressWarnings(PHPMD.CouplingBetweenObjects)
 */
class Remove extends \Magento\Wishlist\Controller\Index\Remove
{

    public function __construct(
        Action\Context $context,
        WishlistProviderInterface $wishlistProvider,
        Validator $formKeyValidator,
        WishlistHelper $wishlistHelper,
        \Magento\Framework\Controller\Result\JsonFactory $resultJsonFactory
    ) {
        parent::__construct($context, $wishlistProvider, $formKeyValidator);
        $this->wishlistHelper = $wishlistHelper;
        $this->resultJsonFactory = $resultJsonFactory;
    }

    /**
     * Remove item
     *
     * @return \Magento\Framework\Controller\Result\Redirect
     * @throws NotFoundException
     */
    public function execute()
    {
        /** @var \Magento\Framework\Controller\Result\Redirect $resultRedirect */
        $resultRedirect = $this->resultFactory->create(ResultFactory::TYPE_REDIRECT);
        if (!$this->formKeyValidator->validate($this->getRequest())) {
            return $resultRedirect->setPath('*/*/');
        }

        $resultJson = $this->resultJsonFactory->create();

        $id = (int)$this->getRequest()->getParam('product_id');

        $collection = $this->wishlistHelper->getWishlistItemCollection();

        $items = [];

        foreach ($collection as $wishlistItem) {
            if($wishlistItem->getProduct()->getId() == $id){
                $items[] = $wishlistItem;
            }
        }

        foreach ($items as $item) {
            $wishlist = $this->wishlistProvider->getWishlist($item->getWishlistId());
            $item->delete();
            $wishlist->save();
        }

        return $resultJson->setData([
            'product_id' => $id
        ]);
    }
}
